@@ -1,28 +1,27 @@
 use crate::{
 	error::Result,
-	sync::{self, branch::get_branch_name},
+	sync::{self, branch::get_branch_name, RepoPathRef},
 };
 use sync::Head;
 
 ///
 pub struct BranchName {
 	last_result: Option<(Head, String)>,
-	repo_path: String,
+	repo: RepoPathRef,
 }
 
 impl BranchName {
 	///
-	pub fn new(path: &str) -> Self {
+	pub const fn new(repo: RepoPathRef) -> Self {
 		Self {
-			repo_path: path.to_string(),
+			repo,
 			last_result: None,
 		}
 	}
 
 	///
 	pub fn lookup(&mut self) -> Result<String> {
-		let current_head =
-			sync::get_head_tuple(self.repo_path.as_str())?;
+		let current_head = sync::get_head_tuple(&self.repo.borrow())?;
 
 		if let Some((last_head, branch_name)) =
 			self.last_result.as_ref()
@@ -41,7 +40,7 @@ impl BranchName {
 	}
 
 	fn fetch(&mut self, head: Head) -> Result<String> {
-		let name = get_branch_name(self.repo_path.as_str())?;
+		let name = get_branch_name(&self.repo.borrow())?;
 		self.last_result = Some((head, name.clone()));
 		Ok(name)
 	}
