@@ -104,6 +104,11 @@ impl BranchInfo {
 
 		None
 	}
+
+	/// returns whether branch is local
+	pub const fn is_local(&self) -> bool {
+		matches!(self.details, BranchDetails::Local(_))
+	}
 }
 
 ///
@@ -243,6 +248,25 @@ pub fn get_branch_remote(
 	}
 }
 
+/// Retrieve the upstream merge of a local `branch`,
+/// configured in "branch.*.merge"
+///
+/// For details check git2 `branch_upstream_merge`
+pub fn get_branch_upstream_merge(
+	repo_path: &RepoPath,
+	branch: &str,
+) -> Result<Option<String>> {
+	let repo = repo(repo_path)?;
+	let branch = repo.find_branch(branch, BranchType::Local)?;
+	let reference = bytes2string(branch.get().name_bytes())?;
+	let remote_name = repo.branch_upstream_merge(&reference).ok();
+	if let Some(remote_name) = remote_name {
+		Ok(Some(bytes2string(remote_name.as_ref())?))
+	} else {
+		Ok(None)
+	}
+}
+
 /// returns whether the pull merge strategy is set to rebase
 pub fn config_is_pull_rebase(repo_path: &RepoPath) -> Result<bool> {
 	let repo = repo(repo_path)?;
@@ -252,7 +276,7 @@ pub fn config_is_pull_rebase(repo_path: &RepoPath) -> Result<bool> {
 		let value =
 			rebase.value().map(String::from).unwrap_or_default();
 		return Ok(value == "true");
-	};
+	}
 
 	Ok(false)
 }
@@ -673,6 +697,49 @@ mod tests_branches {
 
 		assert!(get_branch_remote(repo_path, "foo").is_err());
 	}
+
+	#[test]
+	fn test_branch_no_upstream_merge_config() {
+		let (_r, repo) = repo_init().unwrap();
+		let root = repo.path().parent().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
+
+		let upstream_merge_res =
+			get_branch_upstream_merge(repo_path, "master");
+		assert!(
+			upstream_merge_res.is_ok_and(|v| v.as_ref().is_none())
+		);
+	}
+
+	#[test]
+	fn test_branch_with_upstream_merge_config() {
+		let (_r, repo) = repo_init().unwrap();
+		let root = repo.path().parent().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
+
+		let branch_name = "master";
+		let upstream_merge = "refs/heads/master";
+
+		let mut config = repo.config().unwrap();
+		config
+			.set_str(
+				&format!("branch.{branch_name}.merge"),
+				upstream_merge,
+			)
+			.expect("fail set branch merge config");
+
+		let upstream_merge_res =
+			get_branch_upstream_merge(repo_path, branch_name);
+		assert!(upstream_merge_res
+			.as_ref()
+			.is_ok_and(|v| v.as_ref().is_some()));
+		assert_eq!(
+			&upstream_merge_res.unwrap().unwrap(),
+			upstream_merge
+		);
+	}
 }
 
 #[cfg(test)]
@@ -955,7 +1022,7 @@ mod test_remote_branches {
 	}
 
 	#[test]
-	fn test_checkout_remote_branch_hirachical() {
+	fn test_checkout_remote_branch_hierarchical() {
 		let (r1_dir, _repo) = repo_init_bare().unwrap();
 
 		let (clone1_dir, clone1) =
