@@ -87,6 +87,42 @@ impl CommitDetails {
 	}
 }
 
+/// Get the author of a commit.
+pub fn get_author_of_commit<'a>(
+	commit: &'a git2::Commit<'a>,
+	mailmap: &git2::Mailmap,
+) -> git2::Signature<'a> {
+	match commit.author_with_mailmap(mailmap) {
+		Ok(author) => author,
+		Err(e) => {
+			log::error!(
+				"Couldn't get author with mailmap for {} (message: {:?}): {e}",
+				commit.id(),
+				commit.message(),
+			);
+			commit.author()
+		}
+	}
+}
+
+/// Get the committer of a commit.
+pub fn get_committer_of_commit<'a>(
+	commit: &'a git2::Commit<'a>,
+	mailmap: &git2::Mailmap,
+) -> git2::Signature<'a> {
+	match commit.committer_with_mailmap(mailmap) {
+		Ok(committer) => committer,
+		Err(e) => {
+			log::error!(
+				"Couldn't get committer with mailmap for {} (message: {:?}): {e}",
+				commit.id(),
+				commit.message(),
+			);
+			commit.committer()
+		}
+	}
+}
+
 ///
 pub fn get_commit_details(
 	repo_path: &RepoPath,
@@ -95,11 +131,17 @@ pub fn get_commit_details(
 	scope_time!("get_commit_details");
 
 	let repo = repo(repo_path)?;
+	let mailmap = repo.mailmap()?;
 
 	let commit = repo.find_commit(id.into())?;
 
-	let author = CommitSignature::from(&commit.author());
-	let committer = CommitSignature::from(&commit.committer());
+	let author = CommitSignature::from(&get_author_of_commit(
+		&commit, &mailmap,
+	));
+	let committer = CommitSignature::from(&get_committer_of_commit(
+		&commit, &mailmap,
+	));
+
 	let committer = if author == committer {
 		None
 	} else {
