@@ -1,7 +1,13 @@
 use std::fmt::Display;
 
 use super::RepoPath;
-use crate::{error::Result, sync::repository::repo};
+use crate::{
+	error::Result,
+	sync::{
+		commit_details::get_author_of_commit,
+		repository::{gix_repo, repo},
+	},
+};
 use git2::{Commit, Error, Oid};
 use scopetime::scope_time;
 use unicode_truncate::UnicodeTruncateStr;
@@ -46,6 +52,18 @@ impl CommitId {
 		let commit_obj = repo.revparse_single(revision)?;
 		Ok(commit_obj.id().into())
 	}
+
+	/// Tries to convert a &str representation of a commit id into
+	/// a `CommitId`
+	pub fn from_str_unchecked(commit_id_str: &str) -> Result<Self> {
+		match Oid::from_str(commit_id_str) {
+			Err(e) => Err(crate::Error::Generic(format!(
+				"Could not convert {}",
+				e.message()
+			))),
+			Ok(v) => Ok(Self::new(v)),
+		}
+	}
 }
 
 impl Display for CommitId {
@@ -69,8 +87,32 @@ impl From<Oid> for CommitId {
 	}
 }
 
+impl From<gix::ObjectId> for CommitId {
+	fn from(object_id: gix::ObjectId) -> Self {
+		#[allow(clippy::expect_used)]
+		let oid = Oid::from_bytes(object_id.as_bytes()).expect("`Oid::from_bytes(object_id.as_bytes())` is expected to never fail");
+
+		Self::new(oid)
+	}
+}
+
+impl From<gix::Commit<'_>> for CommitId {
+	fn from(commit: gix::Commit<'_>) -> Self {
+		#[allow(clippy::expect_used)]
+		let oid = Oid::from_bytes(commit.id().as_bytes()).expect("`Oid::from_bytes(commit.id().as_bytes())` is expected to never fail");
+
+		Self::new(oid)
+	}
+}
+
+impl From<CommitId> for gix::ObjectId {
+	fn from(id: CommitId) -> Self {
+		Self::from_bytes_or_panic(id.0.as_bytes())
+	}
+}
+
 ///
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct CommitInfo {
 	///
 	pub message: String,
@@ -91,6 +133,7 @@ pub fn get_commits_info(
 	scope_time!("get_commits_info");
 
 	let repo = repo(repo_path)?;
+	let mailmap = repo.mailmap()?;
 
 	let commits = ids
 		.iter()
@@ -101,10 +144,12 @@ pub fn get_commits_info(
 	let res = commits
 		.map(|c: Commit| {
 			let message = get_message(&c, Some(message_length_limit));
-			let author = c.author().name().map_or_else(
-				|| String::from("<unknown>"),
-				String::from,
-			);
+			let author = get_author_of_commit(&c, &mailmap)
+				.name()
+				.map_or_else(
+					|| String::from("<unknown>"),
+					String::from,
+				);
 			CommitInfo {
 				message,
 				author,
@@ -124,23 +169,33 @@ pub fn get_commit_info(
 ) -> Result<CommitInfo> {
 	scope_time!("get_commit_info");
 
-	let repo = repo(repo_path)?;
+	let repo: gix::Repository = gix_repo(repo_path)?;
+	let mailmap = repo.open_mailmap();
 
-	let commit = repo.find_commit((*commit_id).into())?;
-	let author = commit.author();
+	let commit = repo.find_commit(*commit_id)?;
+	let commit_ref = commit.decode()?;
+
+	let message = gix_get_message(&commit_ref, None);
+
+	let author = commit_ref.author();
+
+	let author = mailmap.try_resolve(author).map_or_else(
+		|| author.name.into(),
+		|signature| signature.name,
+	);
 
 	Ok(CommitInfo {
-		message: commit.message().unwrap_or("").into(),
-		author: author.name().unwrap_or("<unknown>").into(),
-		time: commit.time().seconds(),
-		id: CommitId(commit.id()),
+		message,
+		author: author.to_string(),
+		time: commit_ref.time().seconds,
+		id: commit.id().detach().into(),
 	})
 }
 
 /// if `message_limit` is set the message will be
 /// limited to the first line and truncated to fit
 pub fn get_message(
-	c: &Commit,
+	c: &git2::Commit,
 	message_limit: Option<usize>,
 ) -> String {
 	let msg = String::from_utf8_lossy(c.message_bytes());
@@ -155,6 +210,24 @@ pub fn get_message(
 	)
 }
 
+/// if `message_limit` is set the message will be
+/// limited to the first line and truncated to fit
+pub fn gix_get_message(
+	commit_ref: &gix::objs::CommitRef,
+	message_limit: Option<usize>,
+) -> String {
+	let message = commit_ref.message.to_string();
+	let message = message.trim();
+
+	message_limit.map_or_else(
+		|| message.to_string(),
+		|limit| {
+			let message = message.lines().next().unwrap_or_default();
+			message.unicode_truncate(limit).0.to_string()
+		},
+	)
+}
+
 #[cfg(test)]
 mod tests {
 	use super::get_commits_info;
@@ -189,6 +262,12 @@ mod tests {
 		assert_eq!(res[0].author.as_str(), "name");
 		assert_eq!(res[1].message.as_str(), "commit1");
 
+		File::create(root.join(".mailmap"))?
+			.write_all(b"new name <newemail> <email>")?;
+		let res = get_commits_info(repo_path, &[c2], 50).unwrap();
+
+		assert_eq!(res[0].author.as_str(), "new name");
+
 		Ok(())
 	}
 
