@@ -1,6 +1,3 @@
-//TODO: hopefully released in next rust (see https://github.com/rust-lang/rust-clippy/issues/9440)
-#![allow(clippy::use_self)]
-
 use crate::error::Result;
 use git2::Repository;
 use scopetime::scope_time;
@@ -11,10 +8,11 @@ use super::{repository::repo, RepoPath};
 // see https://git-scm.com/docs/git-config#Documentation/git-config.txt-statusshowUntrackedFiles
 /// represents the `status.showUntrackedFiles` git config state
 #[derive(
-	Hash, Copy, Clone, PartialEq, Eq, Serialize, Deserialize,
+	Hash, Copy, Clone, Default, PartialEq, Eq, Serialize, Deserialize,
 )]
 pub enum ShowUntrackedFilesConfig {
 	///
+	#[default]
 	No,
 	///
 	Normal,
@@ -22,12 +20,6 @@ pub enum ShowUntrackedFilesConfig {
 	All,
 }
 
-impl Default for ShowUntrackedFilesConfig {
-	fn default() -> Self {
-		Self::No
-	}
-}
-
 impl ShowUntrackedFilesConfig {
 	///
 	pub const fn include_none(self) -> bool {
@@ -59,9 +51,57 @@ pub fn untracked_files_config_repo(
 		}
 	}
 
+	// This does not reflect how git works according to its docs that say: "If this variable is not
+	// specified, it defaults to `normal`."
+	//
+	// https://git-scm.com/docs/git-config#Documentation/git-config.txt-statusshowUntrackedFiles
+	//
+	// Note that this might become less relevant over time as more code gets migrated to `gitoxide`
+	// because `gitoxide` respects `status.showUntrackedFiles` by default.
 	Ok(ShowUntrackedFilesConfig::All)
 }
 
+// see https://git-scm.com/docs/git-config#Documentation/git-config.txt-pushdefault
+/// represents `push.default` git config
+#[derive(PartialEq, Default, Eq)]
+pub enum PushDefaultStrategyConfig {
+	Nothing,
+	Current,
+	Upstream,
+	#[default]
+	Simple,
+	Matching,
+}
+
+impl<'a> TryFrom<&'a str> for PushDefaultStrategyConfig {
+	type Error = crate::Error;
+	fn try_from(
+		value: &'a str,
+	) -> std::result::Result<Self, Self::Error> {
+		match value {
+			"nothing" => Ok(Self::Nothing),
+			"current" => Ok(Self::Current),
+			"upstream" | "tracking" => Ok(Self::Upstream),
+			"simple" => Ok(Self::Simple),
+			"matching" => Ok(Self::Matching),
+			_ => Err(crate::Error::GitConfig(format!(
+				"malformed value for push.default: {value}, must be one of nothing, matching, simple, upstream or current"
+			))),
+		}
+	}
+}
+
+pub fn push_default_strategy_config_repo(
+	repo: &Repository,
+) -> Result<PushDefaultStrategyConfig> {
+	(get_config_string_repo(repo, "push.default")?).map_or_else(
+		|| Ok(PushDefaultStrategyConfig::default()),
+		|entry_str| {
+			PushDefaultStrategyConfig::try_from(entry_str.as_str())
+		},
+	)
+}
+
 ///
 pub fn untracked_files_config(
 	repo_path: &RepoPath,
