@@ -1,4 +1,3 @@
-#![allow(dead_code)]
 use super::{CommitId, SharedCommitFilterFn};
 use crate::error::Result;
 use git2::{Commit, Oid, Repository};
@@ -134,7 +133,7 @@ impl<'a> LogWalkerWithoutFilter<'a> {
 		// reason this is 2^14, so benchmarking might reveal that there’s better values.
 		repo.object_cache_size_if_unset(2_usize.pow(14));
 
-		let commit = repo.head()?.peel_to_commit_in_place()?;
+		let commit = repo.head()?.peel_to_commit()?;
 
 		let tips = [commit.id];
 
@@ -162,10 +161,7 @@ impl<'a> LogWalkerWithoutFilter<'a> {
 		let mut count = 0_usize;
 
 		while let Some(Ok(info)) = self.walk.next() {
-			let bytes = info.id.as_bytes();
-			let commit_id: CommitId = Oid::from_bytes(bytes)?.into();
-
-			out.push(commit_id);
+			out.push(info.id.into());
 
 			count += 1;
 
@@ -185,6 +181,7 @@ mod tests {
 	use super::*;
 	use crate::error::Result;
 	use crate::sync::commit_filter::{SearchFields, SearchOptions};
+	use crate::sync::repository::gix_repo;
 	use crate::sync::tests::write_commit_file;
 	use crate::sync::{
 		commit, get_commits_info, stage_add_file,
@@ -270,10 +267,7 @@ mod tests {
 		stage_add_file(repo_path, file_path).unwrap();
 		let oid2 = commit(repo_path, "commit2").unwrap();
 
-		let mut repo: gix::Repository =
-				gix::ThreadSafeRepository::discover_with_environment_overrides(repo_path.gitpath())
-						.map(Into::into)
-						.unwrap();
+		let mut repo: gix::Repository = gix_repo(repo_path)?;
 		let mut walk = LogWalkerWithoutFilter::new(&mut repo, 100)?;
 		let mut items = Vec::new();
 		assert!(matches!(walk.read(&mut items), Ok(2)));
