@@ -39,7 +39,7 @@ pub use blame::{blame_file, BlameHunk, FileBlame};
 pub use branch::{
 	branch_compare_upstream, checkout_branch, checkout_commit,
 	config_is_pull_rebase, create_branch, delete_branch,
-	get_branch_remote, get_branches_info,
+	get_branch_remote, get_branch_upstream_merge, get_branches_info,
 	merge_commit::merge_upstream_commit,
 	merge_ff::branch_merge_upstream_fastforward,
 	merge_rebase::merge_upstream_rebase, rename::rename_branch,
@@ -67,7 +67,8 @@ pub use diff::get_diff_commit;
 pub use git2::BranchType;
 pub use hooks::{
 	hooks_commit_msg, hooks_post_commit, hooks_pre_commit,
-	hooks_prepare_commit_msg, HookResult, PrepareCommitMsgSource,
+	hooks_pre_push, hooks_prepare_commit_msg, HookResult,
+	PrepareCommitMsgSource,
 };
 pub use hunks::{reset_hunk, stage_hunk, unstage_hunk};
 pub use ignore::add_to_ignore;
@@ -84,7 +85,7 @@ pub use remotes::{
 	get_remote_url, get_remotes, push::AsyncProgress, rename_remote,
 	tags::PushTagsProgress, update_remote_url, validate_remote_name,
 };
-pub(crate) use repository::repo;
+pub(crate) use repository::{gix_repo, repo};
 pub use repository::{RepoPath, RepoPathRef};
 pub use reset::{reset_repo, reset_stage, reset_workdir};
 pub use reword::reword;
@@ -123,7 +124,7 @@ pub mod tests {
 	};
 	use crate::error::Result;
 	use git2::Repository;
-	use std::{path::Path, process::Command};
+	use std::{ffi::OsStr, path::Path, process::Command};
 	use tempfile::TempDir;
 
 	///
@@ -144,11 +145,19 @@ pub mod tests {
 
 	///
 	pub fn repo_init() -> Result<(TempDir, Repository)> {
+		repo_init_with_prefix("gitui")
+	}
+
+	///
+	#[inline]
+	pub fn repo_init_with_prefix(
+		prefix: impl AsRef<OsStr>,
+	) -> Result<(TempDir, Repository)> {
 		init_log();
 
 		sandbox_config_files();
 
-		let td = TempDir::new()?;
+		let td = TempDir::with_prefix(prefix)?;
 		let repo = Repository::init(td.path())?;
 		{
 			let mut config = repo.config()?;
