@@ -26,10 +26,16 @@ pub struct Head {
 
 ///
 pub fn repo_open_error(repo_path: &RepoPath) -> Option<String> {
-	Repository::open_ext(
+	if let Err(e) = Repository::open_ext(
 		repo_path.gitpath(),
 		RepositoryOpenFlags::FROM_ENV,
 		Vec::<&Path>::new(),
+	) {
+		return Some(e.to_string());
+	}
+
+	gix::ThreadSafeRepository::discover_with_environment_overrides(
+		repo_path.gitpath(),
 	)
 	.map_or_else(|e| Some(e.to_string()), |_| None)
 }
@@ -230,6 +236,7 @@ mod tests {
 		},
 	};
 	use std::{
+		env,
 		fs::{self, remove_file, File},
 		io::Write,
 		path::Path,
@@ -242,7 +249,7 @@ mod tests {
 		let root = repo.path().parent().unwrap();
 		let repo_path = root.as_os_str().to_str().unwrap();
 
-		assert!(!stage_add_file(&repo_path.into(), file_path).is_ok());
+		assert!(stage_add_file(&repo_path.into(), file_path).is_err());
 	}
 
 	#[test]
@@ -270,6 +277,44 @@ mod tests {
 		assert_eq!(get_statuses(repo_path), (1, 1));
 	}
 
+	#[test]
+	fn test_staging_one_file_from_different_sub_directory() {
+		// This test case covers an interaction between current working directory and the way
+		// `gitoxide` handles pathspecs.
+		//
+		// When staging a new file in one sub-directory, then running running `get_status` in a
+		// different sub-directory, `repo.pathspec` in `get_status` has to initialized with
+		// `empty_patterns_match_prefix` set to `false` for `get_status` to report the staged file’s
+		// status.
+		let file_path = Path::new("untracked/file1.txt");
+		let (_td, repo) = repo_init().unwrap();
+		let root = repo.path().parent().unwrap();
+		let repo_path: &RepoPath =
+			&root.as_os_str().to_str().unwrap().into();
+
+		fs::create_dir(root.join("untracked")).unwrap();
+
+		File::create(root.join(file_path))
+			.unwrap()
+			.write_all(b"test file1 content")
+			.unwrap();
+
+		let sub_dir_path = root.join("unrelated");
+
+		fs::create_dir(root.join("unrelated")).unwrap();
+
+		let current_dir = env::current_dir().unwrap();
+		env::set_current_dir(sub_dir_path).unwrap();
+
+		assert_eq!(get_statuses(repo_path), (1, 0));
+
+		stage_add_file(repo_path, file_path).unwrap();
+
+		assert_eq!(get_statuses(repo_path), (0, 1));
+
+		env::set_current_dir(current_dir).unwrap();
+	}
+
 	#[test]
 	fn test_staging_folder() -> Result<()> {
 		let (_td, repo) = repo_init().unwrap();
@@ -289,6 +334,8 @@ mod tests {
 		File::create(root.join(Path::new("a/f3.txt")))?
 			.write_all(b"foo")?;
 
+		repo.config()?.set_str("status.showUntrackedFiles", "all")?;
+
 		assert_eq!(status_count(StatusType::WorkingDir), 3);
 
 		stage_add_all(repo_path, "a/d", None).unwrap();
@@ -351,6 +398,8 @@ mod tests {
 		File::create(root.join(Path::new("f3.txt")))?
 			.write_all(b"foo")?;
 
+		repo.config()?.set_str("status.showUntrackedFiles", "all")?;
+
 		assert_eq!(get_statuses(repo_path), (3, 0));
 
 		repo.config()?.set_str("status.showUntrackedFiles", "no")?;
@@ -399,7 +448,7 @@ mod tests {
 		assert_eq!(status_count(StatusType::Stage), 1);
 	}
 
-	// see https://github.com/extrawurst/gitui/issues/108
+	// see https://github.com/gitui-org/gitui/issues/108
 	#[test]
 	fn test_staging_sub_git_folder() -> Result<()> {
 		let (_td, repo) = repo_init().unwrap();
@@ -440,7 +489,7 @@ mod tests {
 		let repo_path: &RepoPath =
 			&root.as_os_str().to_str().unwrap().into();
 
-		assert!(!get_head(repo_path).is_ok());
+		assert!(get_head(repo_path).is_err());
 
 		Ok(())
 	}
