@@ -3,7 +3,7 @@ use git2::Repository;
 use crate::{error::Result, HookResult, HooksError};
 
 use std::{
-	env,
+	ffi::{OsStr, OsString},
 	path::{Path, PathBuf},
 	process::Command,
 	str::FromStr,
@@ -17,6 +17,7 @@ pub struct HookPaths {
 
 const CONFIG_HOOKS_PATH: &str = "core.hooksPath";
 const DEFAULT_HOOKS_PATH: &str = "hooks";
+const ENOEXEC: i32 = 8;
 
 impl HookPaths {
 	/// `core.hooksPath` always takes precedence.
@@ -41,16 +42,8 @@ impl HookPaths {
 		if let Some(config_path) = Self::config_hook_path(repo)? {
 			let hooks_path = PathBuf::from(config_path);
 
-			let hook = hooks_path.join(hook);
-
-			let hook = shellexpand::full(
-				hook.as_os_str()
-					.to_str()
-					.ok_or(HooksError::PathToString)?,
-			)?;
-
-			let hook = PathBuf::from_str(hook.as_ref())
-				.map_err(|_| HooksError::PathToString)?;
+			let hook =
+				Self::expand_path(&hooks_path.join(hook), &pwd)?;
 
 			return Ok(Self {
 				git: git_dir,
@@ -66,6 +59,41 @@ impl HookPaths {
 		})
 	}
 
+	/// Expand path according to the rule of githooks and config
+	/// core.hooksPath
+	fn expand_path(path: &Path, pwd: &Path) -> Result<PathBuf> {
+		let hook_expanded = shellexpand::full(
+			path.as_os_str()
+				.to_str()
+				.ok_or(HooksError::PathToString)?,
+		)?;
+		let hook_expanded = PathBuf::from_str(hook_expanded.as_ref())
+			.map_err(|_| HooksError::PathToString)?;
+
+		// `man git-config`:
+		//
+		// > A relative path is taken as relative to the
+		// > directory where the hooks are run (see the
+		// > "DESCRIPTION" section of githooks[5]).
+		//
+		// `man githooks`:
+		//
+		// > Before Git invokes a hook, it changes its
+		// > working directory to either $GIT_DIR in a bare
+		// > repository or the root of the working tree in a
+		// > non-bare repository.
+		//
+		// I.e. relative paths in core.hooksPath in non-bare
+		// repositories are always relative to GIT_WORK_TREE.
+		Ok({
+			if hook_expanded.is_absolute() {
+				hook_expanded
+			} else {
+				pwd.join(hook_expanded)
+			}
+		})
+	}
+
 	fn config_hook_path(repo: &Repository) -> Result<Option<String>> {
 		Ok(repo.config()?.get_string(CONFIG_HOOKS_PATH).ok())
 	}
@@ -107,30 +135,80 @@ impl HookPaths {
 	/// this function calls hook scripts based on conventions documented here
 	/// see <https://git-scm.com/docs/githooks>
 	pub fn run_hook(&self, args: &[&str]) -> Result<HookResult> {
+		self.run_hook_os_str(args)
+	}
+
+	/// this function calls hook scripts based on conventions documented here
+	/// see <https://git-scm.com/docs/githooks>
+	pub fn run_hook_os_str<I, S>(&self, args: I) -> Result<HookResult>
+	where
+		I: IntoIterator<Item = S> + Copy,
+		S: AsRef<OsStr>,
+	{
 		let hook = self.hook.clone();
+		log::trace!(
+			"run hook '{}' in '{}'",
+			hook.display(),
+			self.pwd.display()
+		);
 
-		let arg_str = format!("{:?} {}", hook, args.join(" "));
-		// Use -l to avoid "command not found" on Windows.
-		let bash_args =
-			vec!["-l".to_string(), "-c".to_string(), arg_str];
+		let run_command = |command: &mut Command| {
+			command
+				.args(args)
+				.current_dir(&self.pwd)
+				.with_no_window()
+				.output()
+		};
 
-		log::trace!("run hook '{:?}' in '{:?}'", hook, self.pwd);
+		let output = if cfg!(windows) {
+			// execute hook in shell
+			let command = {
+				// SEE: https://pubs.opengroup.org/onlinepubs/9699919799/utilities/V3_chap02.html#tag_18_02_02
+				// Enclosing characters in single-quotes ( '' ) shall preserve the literal value of each character within the single-quotes.
+				// A single-quote cannot occur within single-quotes.
+				const REPLACEMENT: &str = concat!(
+					"'",   // closing single-quote
+					"\\'", // one escaped single-quote (outside of single-quotes)
+					"'",   // new single-quote
+				);
 
-		let git_shell = find_bash_executable()
-			.or_else(find_default_unix_shell)
-			.unwrap_or_else(|| "bash".into());
-		let output = Command::new(git_shell)
-			.args(bash_args)
-			.with_no_window()
-			.current_dir(&self.pwd)
-			// This call forces Command to handle the Path environment correctly on windows,
-			// the specific env set here does not matter
-			// see https://github.com/rust-lang/rust/issues/37519
-			.env(
-				"DUMMY_ENV_TO_FIX_WINDOWS_CMD_RUNS",
-				"FixPathHandlingOnWindows",
+				let mut os_str = OsString::new();
+				os_str.push("'");
+				if let Some(hook) = hook.to_str() {
+					os_str.push(hook.replace('\'', REPLACEMENT));
+				} else {
+					#[cfg(windows)]
+					{
+						use std::os::windows::ffi::OsStrExt;
+						if hook
+							.as_os_str()
+							.encode_wide()
+							.any(|x| x == u16::from(b'\''))
+						{
+							// TODO: escape single quotes instead of failing
+							return Err(HooksError::PathToString);
+						}
+					}
+
+					os_str.push(hook.as_os_str());
+				}
+				os_str.push("'");
+				os_str.push(" \"$@\"");
+
+				os_str
+			};
+			run_command(
+				sh_command().arg("-c").arg(command).arg(&hook),
 			)
-			.output()?;
+		} else {
+			// execute hook directly
+			match run_command(&mut Command::new(&hook)) {
+				Err(err) if err.raw_os_error() == Some(ENOEXEC) => {
+					run_command(sh_command().arg(&hook))
+				}
+				result => result,
+			}
+		}?;
 
 		if output.status.success() {
 			Ok(HookResult::Ok { hook })
@@ -150,6 +228,25 @@ impl HookPaths {
 	}
 }
 
+fn sh_command() -> Command {
+	let mut command = Command::new(gix_path::env::shell());
+
+	if cfg!(windows) {
+		// This call forces Command to handle the Path environment correctly on windows,
+		// the specific env set here does not matter
+		// see https://github.com/rust-lang/rust/issues/37519
+		command.env(
+			"DUMMY_ENV_TO_FIX_WINDOWS_CMD_RUNS",
+			"FixPathHandlingOnWindows",
+		);
+
+		// Use -l to avoid "command not found"
+		command.arg("-l");
+	}
+
+	command
+}
+
 #[cfg(unix)]
 fn is_executable(path: &Path) -> bool {
 	use std::os::unix::fs::PermissionsExt;
@@ -157,7 +254,7 @@ fn is_executable(path: &Path) -> bool {
 	let metadata = match path.metadata() {
 		Ok(metadata) => metadata,
 		Err(e) => {
-			log::error!("metadata error: {}", e);
+			log::error!("metadata error: {e}");
 			return false;
 		}
 	};
@@ -168,40 +265,12 @@ fn is_executable(path: &Path) -> bool {
 }
 
 #[cfg(windows)]
-/// windows does not consider bash scripts to be executable so we consider everything
+/// windows does not consider shell scripts to be executable so we consider everything
 /// to be executable (which is not far from the truth for windows platform.)
 const fn is_executable(_: &Path) -> bool {
 	true
 }
 
-// Find bash.exe, and avoid finding wsl's bash.exe on Windows.
-// None for non-Windows.
-fn find_bash_executable() -> Option<PathBuf> {
-	if cfg!(windows) {
-		Command::new("where.exe")
-			.arg("git")
-			.output()
-			.ok()
-			.map(|out| {
-				PathBuf::from(Into::<String>::into(
-					String::from_utf8_lossy(&out.stdout),
-				))
-			})
-			.as_deref()
-			.and_then(Path::parent)
-			.and_then(Path::parent)
-			.map(|p| p.join("usr/bin/bash.exe"))
-			.filter(|p| p.exists())
-	} else {
-		None
-	}
-}
-
-// Find default shell on Unix-like OS.
-fn find_default_unix_shell() -> Option<PathBuf> {
-	env::var_os("SHELL").map(PathBuf::from)
-}
-
 trait CommandExt {
 	/// The process is a console application that is being run without a
 	/// console window. Therefore, the console handle for the application is
@@ -211,6 +280,7 @@ trait CommandExt {
 	/// or if it used with either `CREATE_NEW_CONSOLE` or `DETACHED_PROCESS`.
 	///
 	/// See: <https://learn.microsoft.com/en-us/windows/win32/procthread/process-creation-flags>
+	#[cfg(windows)]
 	const CREATE_NO_WINDOW: u32 = 0x0800_0000;
 
 	fn with_no_window(&mut self) -> &mut Self;
@@ -232,3 +302,35 @@ impl CommandExt for Command {
 		self
 	}
 }
+
+#[cfg(test)]
+mod test {
+	use super::HookPaths;
+	use std::path::Path;
+
+	#[test]
+	fn test_hookspath_relative() {
+		assert_eq!(
+			HookPaths::expand_path(
+				Path::new("pre-commit"),
+				Path::new("example_git_root"),
+			)
+			.unwrap(),
+			Path::new("example_git_root").join("pre-commit")
+		);
+	}
+
+	#[test]
+	fn test_hookspath_absolute() {
+		let absolute_hook =
+			std::env::current_dir().unwrap().join("pre-commit");
+		assert_eq!(
+			HookPaths::expand_path(
+				&absolute_hook,
+				Path::new("example_git_root"),
+			)
+			.unwrap(),
+			absolute_hook
+		);
+	}
+}
