@@ -1,5 +1,6 @@
 use crate::{
 	accessors,
+	args::CliArgs,
 	cmdbar::CommandBar,
 	components::{
 		command_pump, event_pump, CommandInfo, Component,
@@ -10,16 +11,16 @@ use crate::{
 	options::{Options, SharedOptions},
 	popup_stack::PopupStack,
 	popups::{
-		AppOption, BlameFilePopup, BranchListPopup, CommitPopup,
-		CompareCommitsPopup, ConfirmPopup, CreateBranchPopup,
-		CreateRemotePopup, ExternalEditorPopup, FetchPopup,
-		FileRevlogPopup, FuzzyFindPopup, HelpPopup,
-		InspectCommitPopup, LogSearchPopupPopup, MsgPopup,
-		OptionsPopup, PullPopup, PushPopup, PushTagsPopup,
-		RemoteListPopup, RenameBranchPopup, RenameRemotePopup,
-		ResetPopup, RevisionFilesPopup, StashMsgPopup,
-		SubmodulesListPopup, TagCommitPopup, TagListPopup,
-		UpdateRemoteUrlPopup,
+		AppOption, BlameFilePopup, BranchListPopup,
+		CheckoutOptionPopup, CommitPopup, CompareCommitsPopup,
+		ConfirmPopup, CreateBranchPopup, CreateRemotePopup,
+		ExternalEditorPopup, FetchPopup, FileRevlogPopup,
+		FuzzyFindPopup, GotoLinePopup, HelpPopup, InspectCommitPopup,
+		LogSearchPopupPopup, MsgPopup, OptionsPopup, PullPopup,
+		PushPopup, PushTagsPopup, RemoteListPopup, RenameBranchPopup,
+		RenameRemotePopup, ResetPopup, RevisionFilesPopup,
+		StashMsgPopup, SubmodulesListPopup, TagCommitPopup,
+		TagListPopup, UpdateRemoteUrlPopup,
 	},
 	queue::{
 		Action, AppTabs, InternalEvent, NeedsUpdate, Queue,
@@ -98,6 +99,7 @@ pub struct App {
 	submodule_popup: SubmodulesListPopup,
 	tags_popup: TagListPopup,
 	reset_popup: ResetPopup,
+	checkout_option_popup: CheckoutOptionPopup,
 	cmdbar: RefCell<CommandBar>,
 	tab: usize,
 	revlog: Revlog,
@@ -112,6 +114,7 @@ pub struct App {
 	popup_stack: PopupStack,
 	options: SharedOptions,
 	repo_path_text: String,
+	goto_line_popup: GotoLinePopup,
 
 	// "Flags"
 	requires_redraw: Cell<bool>,
@@ -150,13 +153,14 @@ impl App {
 	///
 	#[allow(clippy::too_many_lines)]
 	pub fn new(
-		repo: RepoPathRef,
+		cliargs: CliArgs,
 		sender_git: Sender<AsyncGitNotification>,
 		sender_app: Sender<AsyncAppNotification>,
 		input: Input,
 		theme: Theme,
 		key_config: KeyConfig,
 	) -> Result<Self> {
+		let repo = RefCell::new(cliargs.repo_path.clone());
 		log::trace!("open repo at: {:?}", &repo);
 
 		let repo_path_text =
@@ -172,7 +176,20 @@ impl App {
 			sender_app,
 		};
 
-		let tab = env.options.borrow().current_tab();
+		let mut select_file: Option<PathBuf> = None;
+		let tab = if let Some(file) = cliargs.select_file {
+			// convert to relative git path
+			if let Ok(abs) = file.canonicalize() {
+				if let Ok(path) = abs.strip_prefix(
+					env.repo.borrow().gitpath().canonicalize()?,
+				) {
+					select_file = Some(Path::new(".").join(path));
+				}
+			}
+			2
+		} else {
+			env.options.borrow().current_tab()
+		};
 
 		let mut app = Self {
 			input,
@@ -217,7 +234,9 @@ impl App {
 			status_tab: Status::new(&env),
 			stashing_tab: Stashing::new(&env),
 			stashlist_tab: StashList::new(&env),
-			files_tab: FilesTab::new(&env),
+			files_tab: FilesTab::new(&env, select_file),
+			checkout_option_popup: CheckoutOptionPopup::new(&env),
+			goto_line_popup: GotoLinePopup::new(&env),
 			tab: 0,
 			queue: env.queue,
 			theme: env.theme,
@@ -275,7 +294,7 @@ impl App {
 				3 => self.stashing_tab.draw(f, chunks_main[1])?,
 				4 => self.stashlist_tab.draw(f, chunks_main[1])?,
 				_ => bail!("unknown tab"),
-			};
+			}
 		}
 
 		self.draw_popups(f)?;
@@ -285,7 +304,7 @@ impl App {
 
 	///
 	pub fn event(&mut self, ev: InputEvent) -> Result<()> {
-		log::trace!("event: {:?}", ev);
+		log::trace!("event: {ev:?}");
 
 		if let InputEvent::Input(ev) = ev {
 			if self.check_hard_exit(&ev) || self.check_quit(&ev) {
@@ -402,7 +421,7 @@ impl App {
 		&mut self,
 		ev: AsyncNotification,
 	) -> Result<()> {
-		log::trace!("update_async: {:?}", ev);
+		log::trace!("update_async: {ev:?}");
 
 		if let AsyncNotification::Git(ev) = ev {
 			self.status_tab.update_git(ev)?;
@@ -481,6 +500,7 @@ impl App {
 			msg_popup,
 			confirm_popup,
 			commit_popup,
+			goto_line_popup,
 			blame_file_popup,
 			file_revlog_popup,
 			stashmsg_popup,
@@ -493,6 +513,7 @@ impl App {
 			fetch_popup,
 			tag_commit_popup,
 			reset_popup,
+			checkout_option_popup,
 			create_branch_popup,
 			create_remote_popup,
 			rename_remote_popup,
@@ -533,6 +554,7 @@ impl App {
 			submodule_popup,
 			tags_popup,
 			reset_popup,
+			checkout_option_popup,
 			create_branch_popup,
 			rename_branch_popup,
 			revision_files_popup,
@@ -544,7 +566,8 @@ impl App {
 			fetch_popup,
 			options_popup,
 			confirm_popup,
-			msg_popup
+			msg_popup,
+			goto_line_popup
 		]
 	);
 
@@ -905,7 +928,18 @@ impl App {
 			InternalEvent::CommitSearch(options) => {
 				self.revlog.search(options);
 			}
-		};
+			InternalEvent::OpenGotoLinePopup(max_line) => {
+				self.goto_line_popup.open(max_line);
+			}
+			InternalEvent::GotoLine(line) => {
+				if self.blame_file_popup.is_visible() {
+					self.blame_file_popup.goto_line(line);
+				}
+			}
+			InternalEvent::CheckoutOption(branch) => {
+				self.checkout_option_popup.open(branch)?;
+			}
+		}
 
 		Ok(flags)
 	}
@@ -997,7 +1031,7 @@ impl App {
 					undo_last_commit(&self.repo.borrow())
 				);
 			}
-		};
+		}
 
 		flags.insert(NeedsUpdate::ALL);
 
@@ -1019,7 +1053,7 @@ impl App {
 			));
 
 			self.tags_popup.update_tags()?;
-		};
+		}
 		Ok(())
 	}
 
@@ -1061,7 +1095,7 @@ impl App {
 				));
 			}
 			Err(e) => {
-				log::error!("delete remote: {}", e,);
+				log::error!("delete remote: {e:?}");
 				self.queue.push(InternalEvent::ShowErrorMsg(
 					format!("delete remote error:\n{e}",),
 				));
