@@ -2,14 +2,14 @@ use std::sync::{Arc, Condvar, Mutex};
 
 /// combines a `Mutex` and `Condvar` to allow waiting for a change in the variable protected by the `Mutex`
 #[derive(Clone, Debug)]
-pub struct NotifyableMutex<T>
+pub struct NotifiableMutex<T>
 where
 	T: Send + Sync,
 {
 	data: Arc<(Mutex<T>, Condvar)>,
 }
 
-impl<T> NotifyableMutex<T>
+impl<T> NotifiableMutex<T>
 where
 	T: Send + Sync,
 {
