@@ -171,7 +171,7 @@ impl FileRevlogPopup {
 					{
 						if params == diff_params {
 							self.diff.update(
-								open_request.file_path.to_string(),
+								open_request.file_path.clone(),
 								false,
 								last,
 							);
@@ -251,8 +251,8 @@ impl FileRevlogPopup {
 		};
 		let revisions = self.get_max_selection();
 
-		self.open_request.as_ref().map_or(
-			"<no history available>".into(),
+		self.open_request.as_ref().map_or_else(
+			|| "<no history available>".into(),
 			|open_request| {
 				strings::file_log_title(
 					&open_request.file_path,
@@ -263,7 +263,7 @@ impl FileRevlogPopup {
 		)
 	}
 
-	fn get_rows(&self, now: DateTime<Local>) -> Vec<Row> {
+	fn get_rows(&self, now: DateTime<Local>) -> Vec<Row<'_>> {
 		self.items
 			.iter()
 			.map(|entry| {
@@ -521,7 +521,7 @@ impl Component for FileRevlogPopup {
 								InspectCommitOpen::new(commit_id),
 							),
 						));
-					};
+					}
 				} else if key_match(key, self.key_config.keys.blame) {
 					if let Some(open_request) =
 						self.open_request.clone()
