@@ -348,7 +348,7 @@ impl Status {
 
 					self.diff.focus(true);
 				}
-			};
+			}
 
 			self.update_diff()?;
 
@@ -613,7 +613,7 @@ impl Status {
 		let is_ahead = self
 			.git_branch_state
 			.as_ref()
-			.map_or(true, |state| state.ahead > 0);
+			.is_none_or(|state| state.ahead > 0);
 
 		is_ahead && self.remotes.has_remote_for_push
 	}
