@@ -2,11 +2,10 @@ use asyncgit::{
 	asyncjob::{AsyncJob, RunParams},
 	ProgressPercent,
 };
-use once_cell::sync::Lazy;
+use once_cell::sync::{Lazy, OnceCell};
 use ratatui::text::{Line, Span};
 use scopetime::scope_time;
 use std::{
-	ffi::OsStr,
 	ops::Range,
 	path::{Path, PathBuf},
 	sync::{Arc, Mutex},
@@ -15,13 +14,15 @@ use std::{
 use syntect::{
 	highlighting::{
 		FontStyle, HighlightState, Highlighter,
-		RangedHighlightIterator, Style, ThemeSet,
+		RangedHighlightIterator, Style, Theme, ThemeSet,
 	},
 	parsing::{ParseState, ScopeStack, SyntaxSet},
 };
 
 use crate::{AsyncAppNotification, SyntaxHighlightProgress};
 
+pub const DEFAULT_SYNTAX_THEME: &str = "base16-eighties.dark";
+
 struct SyntaxLine {
 	items: Vec<(Style, usize, Range<usize>)>,
 }
@@ -34,7 +35,7 @@ pub struct SyntaxText {
 
 static SYNTAX_SET: Lazy<SyntaxSet> =
 	Lazy::new(two_face::syntax::extra_no_newlines);
-static THEME_SET: Lazy<ThemeSet> = Lazy::new(ThemeSet::load_defaults);
+static THEME: OnceCell<Theme> = OnceCell::new();
 
 pub struct AsyncProgressBuffer {
 	current: usize,
@@ -60,7 +61,7 @@ impl AsyncProgressBuffer {
 
 	pub fn update(&mut self, current: usize) -> bool {
 		self.current = current;
-		self.last_send.map_or(true, |last_send| {
+		self.last_send.is_none_or(|last_send| {
 			last_send.elapsed() > self.min_interval
 		})
 	}
@@ -71,32 +72,42 @@ impl SyntaxText {
 		text: String,
 		file_path: &Path,
 		params: &RunParams<AsyncAppNotification, ProgressPercent>,
+		syntax: &str,
 	) -> asyncgit::Result<Self> {
 		scope_time!("syntax_highlighting");
-
 		let mut state = {
 			scope_time!("syntax_highlighting.0");
-			let syntax = file_path
-				.extension()
-				.and_then(OsStr::to_str)
-				.map_or_else(
-					|| {
-						SYNTAX_SET.find_syntax_by_path(
-							file_path.to_str().unwrap_or_default(),
-						)
-					},
-					|ext| SYNTAX_SET.find_syntax_by_extension(ext),
-				);
+			let plain_text = || SYNTAX_SET.find_syntax_plain_text();
+			let syntax = SYNTAX_SET
+				.find_syntax_for_file(file_path)
+				.unwrap_or_else(|e| {
+					log::error!("Could not read the file to detect its syntax: {e}");
+					Some(plain_text())
+				})
+				.unwrap_or_else(plain_text);
 
-			ParseState::new(syntax.unwrap_or_else(|| {
-				SYNTAX_SET.find_syntax_plain_text()
-			}))
+			ParseState::new(syntax)
 		};
 
-		let highlighter = Highlighter::new(
-			&THEME_SET.themes["base16-eighties.dark"],
-		);
+		let theme = THEME.get_or_try_init(|| -> Result<Theme, asyncgit::Error> {
+			let theme_path = crate::args::get_app_config_path()
+				.map_err(|e| asyncgit::Error::Generic(e.to_string()))?.join(format!("{syntax}.tmTheme"));
 
+			match ThemeSet::get_theme(&theme_path) {
+				Ok(t) => return Ok(t),
+			    Err(e) => log::info!("could not load '{}': {e}, trying from the set of default themes", theme_path.display()),
+			}
+
+			let mut theme_set = ThemeSet::load_defaults();
+			if let Some(t) = theme_set.themes.remove(syntax) {
+			    return Ok(t);
+			}
+
+			log::error!("the syntax theme '{syntax}' cannot be found. Using default theme ('{DEFAULT_SYNTAX_THEME}') instead");
+			Ok(theme_set.themes.remove(DEFAULT_SYNTAX_THEME).expect("the default theme should be there"))
+		})?;
+
+		let highlighter = Highlighter::new(theme);
 		let mut syntax_lines: Vec<SyntaxLine> = Vec::new();
 
 		let mut highlight_state =
@@ -118,7 +129,7 @@ impl SyntaxText {
 				let ops = state
 					.parse_line(line, &SYNTAX_SET)
 					.map_err(|e| {
-						log::error!("syntax error: {:?}", e);
+						log::error!("syntax error: {e:?}");
 						asyncgit::Error::Generic(
 							"syntax error".to_string(),
 						)
@@ -219,14 +230,20 @@ enum JobState {
 #[derive(Clone, Default)]
 pub struct AsyncSyntaxJob {
 	state: Arc<Mutex<Option<JobState>>>,
+	syntax: String,
 }
 
 impl AsyncSyntaxJob {
-	pub fn new(content: String, path: String) -> Self {
+	pub fn new(
+		content: String,
+		path: String,
+		syntax: String,
+	) -> Self {
 		Self {
 			state: Arc::new(Mutex::new(Some(JobState::Request((
 				content, path,
 			))))),
+			syntax,
 		}
 	}
 
@@ -262,6 +279,7 @@ impl AsyncJob for AsyncSyntaxJob {
 						content,
 						Path::new(&path),
 						&params,
+						&self.syntax,
 					)?;
 					JobState::Response(syntax)
 				}
